@@ -12,7 +12,7 @@ package Mojolicious::Plugin::BootstrapHelpers {
 
     use experimental 'postderef';
 
-    our $VERSION = 0.004;
+    our $VERSION = 0.005;
 
     sub bootstrap_panel {
         my($c, $title, $callback, $content, $attr) = parse_call(@_);
@@ -104,6 +104,7 @@ package Mojolicious::Plugin::BootstrapHelpers {
         my @column_classes = get_column_classes($attr->{'column_information'}, 1);
         $tag_attr = add_classes($tag_attr, 'form-control', { size => 'input-%s' });
         $tag_attr->{'id'} = $id;
+        my $name_attr = $id =~ s{-}{_}r;
 
         my $prepend = delete $tag_attr->{'prepend'};
         my $append = delete $tag_attr->{'append'};
@@ -111,7 +112,7 @@ package Mojolicious::Plugin::BootstrapHelpers {
 
         my $horizontal_before = scalar @column_classes ? qq{<div class="} . (trim join ' ' => @column_classes) . '">' : '';
         my $horizontal_after = scalar @column_classes ? '</div>' : '';
-        my $input = Mojolicious::Plugin::TagHelpers::_input($c, $id, $tag_attr->%*, type => $tagname);
+        my $input = Mojolicious::Plugin::TagHelpers::_input($c, $name_attr, $tag_attr->%*, type => $tagname);
 
         # input group not requested
         if(!defined $prepend && !defined $append) {
@@ -412,6 +413,8 @@ If you want a panel without title, set the title to C<undef>. Note that you can'
 
 The first shortcut, C<success>. This applies C<.panel-success>.
 
+
+
 =head2 Form groups
 
 L<Bootstrap documentation|http://getbootstrap.com/css/#forms>
@@ -425,22 +428,24 @@ L<Bootstrap documentation|http://getbootstrap.com/css/#forms>
         <input class="form-control" id="test_text" name="test_text" type="text" />
     </div>
 
-The first item in the array ref is used for both C<id> and C<name>.
+The first item in the array ref is used for both C<id> and C<name>. Except...
 
 =head3 Input group (before), and large input field
 
-    %= formgroup 'Text test 4', text_field => ['test_text', append => '.00', large]
+    %= formgroup 'Text test 4', text_field => ['test-text', append => '.00', large]
 
     <div class="form-group">
         <label class="control-label" for="test_text">Text test 4</label>
         <div class="input-group">
-            <input class="form-control input-lg" id="test_text" name="test_text" type="text" />
+            <input class="form-control input-lg" id="test-text" name="test_text" type="text" />
             <span class="input-group-addon">.00</span>
         </div>
     </div>
 
 Shortcuts can also be used in this context. Here C<large> applies C<.input-lg>.
 
+If the input name (the first item in the text_field array ref) contains dashes, those are replaced (in the C<name>) to underscores.
+
 =head3 Input group (before and after), and with value
 
     %= formgroup 'Text test 5', text_field => ['test_text', '200', prepend => '$', append => '.00']
@@ -478,7 +483,26 @@ Note the difference with the earlier example. Here C<large> is outside the C<tex
         </div>
     </div>
 
-If the C<form> C<.form-horizontal>, you can set the column widths with the C<cols> attribute. The first item in each array ref is for the label, and the second for the input.
+If the C<form> is C<.form-horizontal>, you can set the column widths with the C<cols> attribute. The first item in each array ref is for the label, and the second for the input.
+
+
+
+=head2 Buttons
+
+L<Bootstrap documentation|http://getbootstrap.com/css/#buttons>
+
+    %= button 'The example 5' => large, warning
+
+    <button class="btn btn-lg btn-warning">The example 5</button>
+
+An ordinary button, with applied shortcuts.
+    
+    %= button 'The example 1' => ['http://www.example.com/'], small
+
+    <a class="btn btn-sm" href="http://www.example.com/">The example 1</a>
+
+If the first argument after the button text is an array ref, it is used to populate C<href> and turns the button into a link. 
+The url is handed off L<url_for|Mojolicious::Controller#url_for>, so this is basically L<link_to|Mojolicious::Plugin::TagHelpers#link_to> with Bootstrap classes.
 
 =head1 OPTIONS
 
